@@ -23,8 +23,10 @@ from alembic import migration
 from oslo_db.sqlalchemy import session as db_session
 from oslo_db.sqlalchemy import utils as oslo_sql_utils
 from oslo_log import log
+from oslo_utils import importutils
 from oslo_utils import timeutils
 import six
+import sqlalchemy
 from sqlalchemy import asc
 from sqlalchemy import desc
 from sqlalchemy.engine import url as sqlalchemy_url
@@ -38,6 +40,9 @@ from aodh.storage import models as alarm_api_models
 from aodh.storage.sqlalchemy import models
 from aodh.storage.sqlalchemy import utils as sql_utils
 
+
+osprofiler_sqlalchemy = importutils.try_import('osprofiler.sqlalchemy')
+
 LOG = log.getLogger(__name__)
 
 AVAILABLE_CAPABILITIES = {
@@ -74,6 +79,11 @@ class Connection(base.Connection):
             options.pop(opt.name, None)
         self._engine_facade = db_session.EngineFacade(self.dress_url(url),
                                                       **options)
+
+        if osprofiler_sqlalchemy:
+            osprofiler_sqlalchemy.add_tracing(sqlalchemy,
+                                              self._engine_facade.get_engine(),
+                                              'db')
         self.conf = conf
 
     @staticmethod
@@ -297,7 +307,8 @@ class Connection(base.Connection):
                                             user_id=row.user_id,
                                             project_id=row.project_id,
                                             on_behalf_of=row.on_behalf_of,
-                                            timestamp=row.timestamp)
+                                            timestamp=row.timestamp,
+                                            severity=row.severity)
 
     def query_alarms(self, filter_expr=None, orderby=None, limit=None):
         """Yields a lists of alarms that match filter."""
